@@ -1,13 +1,16 @@
 import os
 import json
+import requests
 from hashlib import md5
 
-from dataflows import Flow, load, PackageWrapper, dump_to_path
+from dataflows import Flow, load, PackageWrapper, dump_to_path #, printer
+from dataflows.base.schema_validator import ignore
 
 from ...core import BaseDataGenusProcessor, Required, Validator
 from .analyzers import FileFormatDGP, StructureDGP
 from ...config.consts import CONFIG_URL, CONFIG_MODEL_EXTRA_FIELDS, CONFIG_TAXONOMY_CT,\
-    CONFIG_MODEL_MAPPING, CONFIG_TAXONOMY_ID, RESOURCE_NAME
+    CONFIG_MODEL_MAPPING, CONFIG_TAXONOMY_ID, CONFIG_PUBLISH_ALLOWED, RESOURCE_NAME
+from ...config.log import logger
 
 
 class LoaderDGP(BaseDataGenusProcessor):
@@ -60,6 +63,7 @@ class LoaderDGP(BaseDataGenusProcessor):
                         if entry['name'] == field['name']:
                             field.update(entry)
                             break
+                    field.update(field.pop('options', {}))
                     if 'normalize' in field:
                         columnType = normalizationColumnType
                     else:
@@ -69,6 +73,7 @@ class LoaderDGP(BaseDataGenusProcessor):
                             if columnType == entry['name']:
                                 if 'dataType' in entry:
                                     field['type'] = entry['dataType']
+                                field.update(entry.get('options', {}))
                                 break
 
             # Our own additions
@@ -88,23 +93,40 @@ class LoaderDGP(BaseDataGenusProcessor):
 
             config = self.config._unflatten()
             source = config['source']
-            ref_hash = self.hash_key(source, config['structure'])
+            ref_hash = self.hash_key(source, config['structure'], config.get('publish'))
             cache_path = os.path.join('.cache', ref_hash)
             datapackage_path = os.path.join(cache_path, 'datapackage.json')
+            structure_params = self.context._structure_params()
+            session = requests.Session()
+            session.headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.77 Safari/537.36'}
+            loader = load(source.pop('path'), validate=False,
+                          name=RESOURCE_NAME,
+                          **source, **structure_params,
+                          http_session=session,
+                          infer_strategy=load.INFER_PYTHON_TYPES,
+                          cast_strategy=load.CAST_DO_NOTHING,
+                          limit_rows=(
+                              None
+                              if self.config.get(CONFIG_PUBLISH_ALLOWED)
+                              else 5000
+                          ))
 
-            if not os.path.exists(datapackage_path):
-                print('Caching source data into {}'.format(cache_path))
-                structure_params = self.context._structure_params()
-                Flow(
-                    load(source.pop('path'), validate=False,
-                         name=RESOURCE_NAME,
-                         **source, **structure_params),
-                    dump_to_path(cache_path),
+            if self.config.get(CONFIG_PUBLISH_ALLOWED):
+                return Flow(
+                    loader,
                     self.create_fdp(),
-                ).process()
-            print('Using cached source data from {}'.format(cache_path))
-            return Flow(
-                load(datapackage_path, validate=False,
-                     resources=RESOURCE_NAME),
-                self.create_fdp(),
-            )
+                )
+            else:
+                if not os.path.exists(datapackage_path):
+                    logger.info('Caching source data into %s', cache_path)
+                    Flow(
+                        loader,
+                        dump_to_path(cache_path, validator_options=dict(on_error=ignore)),
+                        self.create_fdp(),
+                        # printer(),
+                    ).process()
+                logger.info('Using cached source data from %s', cache_path)
+                return Flow(
+                    load(datapackage_path, resources=RESOURCE_NAME),
+                    self.create_fdp(),
+                )
