@@ -1,6 +1,6 @@
 from .....core import BaseAnalyzer, Validator, Required
 from .....taxonomies import Taxonomy
-from .....config.consts import CONFIG_TAXONOMY_ID, CONFIG_TAXONOMY_CT
+from .....config.consts import CONFIG_TAXONOMY_ID, CONFIG_TAXONOMY_CT, CONFIG_TAXONOMY_SETTINGS
 
 
 class TaxonomyFetcherAnalyzer(BaseAnalyzer):
@@ -13,3 +13,4 @@ class TaxonomyFetcherAnalyzer(BaseAnalyzer):
         tid = self.config.get(CONFIG_TAXONOMY_ID)
         t: Taxonomy = self.context.taxonomies.get(tid)
         self.config[CONFIG_TAXONOMY_CT] = t.column_types
+        self.config[CONFIG_TAXONOMY_SETTINGS] = t.config
